#
# spec file for package qalculate
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define major   14
%define libname libqalculate
Name:           qalculate
Version:        2.2.1
Release:        bp153.2.2.1
Summary:        Multi-purpose desktop calulator application
License:        GPL-2.0+
Group:          Productivity/Scientific/Math
Url:            https://qalculate.github.io/
Source:         https://github.com/Qalculate/libqalculate/releases/download/v%{version}/%{libname}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM (https://github.com/Qalculate/libqalculate/pull/87)
Patch1:         0001-Fix-leaking-of-FDs-created-by-pipe.patch
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  intltool
BuildRequires:  libxml2-devel
BuildRequires:  mpfr-devel
BuildRequires:  perl-XML-Parser
BuildRequires:  pkgconfig
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(icu-uc)
BuildRequires:  pkgconfig(libcurl)

%description
Qalculate is a multi-purpose desktop calculator. Features include
customizable functions, units, arbitrary precision, plotting, and a
graphical interface that uses a one-line fault-tolerant expression
entry (although it supports optional traditional buttons).
This is the commandline interface, named qalc.

%package -n %{libname}%{major}
Summary:        Powerful Calulator Library
Group:          System/Libraries
Suggests:       %{name}
Provides:       %{libname} = %{version}

%description -n %{libname}%{major}
Qalculate is a multi-purpose desktop calculator. Features include
customizable functions, units, arbitrary precision, plotting, and a
graphical interface that uses a one-line fault-tolerant expression
entry.
This is the shared library package.

%package -n %{libname}-devel
Summary:        Header files, libraries and development documentation for %{libname}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       gmp-devel
Requires:       libxml2-devel
Requires:       mpfr-devel

%description -n %{libname}-devel
This package contains the header files and development
documentation for %{libname}. If you like to develop programs using %{libname},
you will need to install %{libname}-devel.

%prep
%setup -q -n %{libname}-%{version}
%autopatch -p1

%build
%configure --disable-static
make %{?_smp_mflags}

%install
%make_install
%find_lang libqalculate
rm -f "%{buildroot}/%{_libdir}"/*.la

%post -n %{libname}%{major} -p /sbin/ldconfig
%postun -n %{libname}%{major} -p /sbin/ldconfig

%files -f libqalculate.lang
%license COPYING
%doc README ChangeLog INSTALL AUTHORS TODO
%{_bindir}/qalc
%{_datadir}/%{name}
%{_datadir}/doc/%{libname}

%files -n %{libname}%{major}
%license COPYING
%{_libdir}/%{libname}.so.%{major}
%{_libdir}/%{libname}.so.%{major}.*

%files -n %{libname}-devel
%license COPYING
%{_includedir}/%{libname}
%{_libdir}/%{libname}.so
%{_libdir}/pkgconfig/%{libname}.pc

%changelog
* Tue May  8 2018 fabian@ritter-vogt.de
- Add patch to fix FD leak (boo#1092329):
  * 0001-Fix-leaking-of-FDs-created-by-pipe.patch
* Sat Mar 10 2018 fabian@ritter-vogt.de
- Use %%license
- Clean .spec file
- Update to 2.2.1:
  * Fix electric constant, magnetic constant, and characteristic impedance of vacuum.
  * Fix handling of Unicode symbols in expressions with quotation marks.
  * Fix segfault in solve() function.
  * sinc() function.
  * Add vacuum_permeability and vacuum_permittivity as alternative names for magnetic and electric constants.
  * Add completion only names to enable completion of Greek letters from the Roman letter names.
  * Suppress gnuplot output in terminal.
* Mon Dec 18 2017 christophe@krop.fr
- Update to 2.2.0
  * Bitcoin support
  * Fix wrong partial calculation of square root in exact mode in some cases
  * Equation solving enhancements
  Check http://qalculate.github.io/news.html for the complete changelog
* Tue Aug 29 2017 fabian@ritter-vogt.de
- Update to 2.0.0:
  * CLN has been replaced with GMP and MPFR for low-level numerical calculations.
  * The Glib dependancy has been removed. It has partly been replaced with libiconv and icu. Libqalculate can be compiled without them and libiconv is only used the CLI application.
  * GVFS and wget have been replaced by libcurl for exchange rates retrieval.
  * Date functions have been rewritten and now support much larger numbers.
  * Trigonometric functions with angle unit other than radians have been fixed.
  * Functions with more than one argument can now also be applied to the RPN stack.
  * New functions: airy(), arg(), besselj(), bessely(), conj(), digamma(), erf(), erfc()
  * Binary installer for Microsoft Windows.
  * Increased efficiency and many minor enhancements and bug fixes.
* Fri Jun  2 2017 wbauer@tmo.at
- Update to 0.9.12:
  * Fixes to unit parsing in adaptive parsing mode, build fixes and other minor bug fixes
- Update to 0.9.11:
  * Mixed units conversion (e.g. "15 in = 1 ft + 3 in" and "3,2 h = 3 h + 12 min")
  * Fixes to unit conversion (e.g. "1/(1 ns) to GHz")
  * Fix slow calculation of exponentiations with big numerators in exponents (e.g. "2^0.333333333")
  * Critical fixes for RPN syntax
  * Fix degree sign
  * Fix transformation of last arguments to vector, when only one last argument (fixes function("1+\x"; 1))
  * Plot functions (makes possible plotting, using gnuplot, in qalc)
  * "Swap, "pop", "copy", "rotate" and "move" commands for RPN stack manipulation in qalc
  * Enable both (or one of) RPN stack and syntax with the "rpn" command in qalc
  * New commands for creation of simple functions and variables (without calculation of the expression) in qalc
  * Various other minor enhancements and bug fixes...
* Thu Jan 19 2017 jengelh@inai.de
- Trim filler words from description.
- Remove unused .la files.
* Thu Jan 12 2017 fabian@ritter-vogt.de
- Update to 0.9.10:
  * Unit conversion fixes (e.g. "1/s to ms" and "1/ns to GHz")
  * Fixed parsing of degrees sign (used in defult symbol for temperature units)
- Update to 0.9.9:
  * libqalculate will no longer cause segmentation faults when using a locale unsupported by the users system
  * Parsing of "today" fixed and "tomorrow" and "yesterday" added
  * Qalculate! now compiles, without errors and warning, using clang
  * New commands/options in qalc which list available variables, functions and units
  * New command in qalcfor deletion of variables
- Update to 0.9.8:
  * Lots of bug fixes and minor improvements
  * Three different parsing modes can be chosen from (providing mainly different handling of implicit multiplication). The default 'adaptive' mode has been enhanced.
  * By default prefixes will not be added to for example imperial units.
  * Changed handling of degrees Celsius and Fahrenheit. Conversion will take place already during parsing.
  * When converting to unit without prefix, no prefix will be added to the result unless the unit expression is prepended with '?' ('0' works in the opposite direction).
  * Option to ignore commas in numbers (for use as thousands separator).
  * Possibility to abort slow number printing without using crash prone thread cancellation (use Calculator::startPrintControl() and related functions).
  * New function: fibonacci (Qalculate! can now tell you that the millionth fibonacci number is approximately 1,953282129 * 10^208987, although for obvious reasons the exact number cannot be displayed).
  * New units: Hartree, Rydberg, Dalton (same as u)
  * Currencies have been updated to reflect the available data from ECB.
  * Physical constant have been updated with the CODATA values from 2014.
  * Use ~/.local and ~/.conf to store configuration and definitions
  * 'to' can now not only be used for conversion to unit expressions. "to bin", "to oct", "to hex" and "to bases" changes number base displayed, "to factors" factorizes, "to fraction" displays as fraction, and "to base" and "to optimal" auto-converts units. (CLI)
- Now using https://github.com/Qalculate/libqalculate as source
- Remove gcc-6-compile.patch, fixed upstream
* Wed May 25 2016 jslaby@suse.com
- add gcc-6-compile.patch: Fix compilation with gcc 6
* Tue Nov 20 2012 nico.kruber@gmail.com
- Fix the SLES build (%%make_install is not expanded on SLES)
* Wed Dec  7 2011 coolo@suse.com
- this is GPL-2.0+
* Mon Mar 14 2011 coolo@novell.com
- the usage of find_lang is mandatory
* Sun Apr 25 2010 masterpatricko@gmail.com
- Update to 0.9.7
  * General build updates and bug fixes, including the ability to build against cln >= 1.2
  * Bug fix for segfaults with some uses of integrate()
  * New Simplified Chinese translation
  * Fix crash with unsupported operator in RPN syntax
  * Fix reduction of vector size
* Fri Sep  5 2008 masterpatricko@gmail.com
- Many small fixes to spec file, with addition of patch to build on openSUSE 11+
* Sun Jun 17 2007 bwalle@suse.de
- update to 0.9.6: bug fixes
* Mon Dec 18 2006 bernhard@suse.de
- new upstream release
* Thu Jun 15 2006 bernhard@links2linux.de
- new upstream release
* Sun May 14 2006 bernhard@links2linux.de
- added BuildRequires gmp-devel
* Sun Mar 19 2006 bernhard@links2linux.de
- new upsream version 0.9.3
* Tue Jan 10 2006 bernhard@links2linux.de
- new upstream version 0.9.2
* Fri Nov  4 2005 bernhard@links2linux.de
- initial package for PackMan
